# Desktop Application for Model Execution (DAME)

## Requeriments

### Singularity 

The application needs Singularity to run the containers. 

- [Installation on Linux](https://sylabs.io/guides/3.5/admin-guide/installation.html#)
- [Installation on Windows](https://sylabs.io/guides/3.5/admin-guide/installation.html#windows)
- [Installation on Mac](https://sylabs.io/singularity-desktop-macos/)


If you would like support for Docker, let us know: [Supoort Docker](https://github.com/mintproject/dame_cli/issues/15)

### Python 3

The applications needs Python. 

- [Installation on Linux](https://realpython.com/installing-python/#linux)
- [Installation on Windows](https://realpython.com/installing-python/#windows)
- [Installation on Mac](https://realpython.com/installing-python/#macos-mac-os-x)

## Installation

To install the execution application, open a terminal and run:

```bash
pip install dame-cli
```
Full documentation of the CLI, including usage examples, can be found at: https://dame-cli.readthedocs.io/en/latest/
